#!/bin/sh
set -e

# This is the list of files that got restored
filelist=$1

# Handle scratchbox specially [Is this needed here?]
if [ -f /targets/links/scratchbox.config ]; then
    . /targets/links/scratchbox.config
    channelsdir="$SBOX_TARGET_DIR//home/user/.mediaplayer-engine"
    channels="$SBOX_TARGET_DIR//home/user/.mediaplayer-engine/radiochannels.m3u"
else
    channelsdir=/home/user/.mediaplayer-engine
    channels=/home/user/.mediaplayer-engine/radiochannels.m3u
fi


# Create file if it didn't exist
if [ ! -f $channels ]; then
    echo "Creating '$channels'"
    (mkdir -p $channelsdir)
    chown -R user:`id -g user` $channelsdir
    touch $channels
fi

# Append pre-installed channels for which no matching url is found in channels.
# The data read into the while loop MUST consist of alternating #EXTINF
# and http://... lines (and nothing else!)
while read extinf && read url; do
    if ! fgrep -q "$url" $channels; then
        echo "$extinf" >>$channels
        echo "$url" >>$channels
    fi
done <<END
#EXTINF:-1,BBC Radio 1     
http://www.bbc.co.uk/radio1/realaudio/media/r1live.ram
#EXTINF:-1,BBC World Service
http://www.bbc.co.uk/worldservice/meta/tx/nb/live_news_au_nb.ram
#EXTINF:-1,BBC World News Summary
http://www.bbc.co.uk/worldservice/meta/tx/nb/summary5min_au_nb.ram 
#EXTINF:-1,BBC Sport Roundup
http://www.bbc.co.uk/worldservice/ram/sportsroundup.ram 
#EXTINF:-1,BBC World Business Report
http://www.bbc.co.uk/worldservice/ram/wbr.ram
END
